#Packages
library("agricolae")
library("car")
library("ggplot2")
library(dplyr)#for manipulating data

st.err <- function(x) {sd(x)/sqrt(length(x))} #funsction to determine the standard error

#Create the environment
setwd("/Volumes/users9/Documents/02 Data/01 EXP1  Nutrilim")

MBPt=read.csv("2015NutriLimMBPt.csv") #read the data

#----------------------------------------------------------------------------- Analysis per amendment
MBP_A<-MBPt
MBP_A$SITE<-factor(ifelse(MBP_A$SOIL=="NUB","Native",ifelse(
  MBP_A$SOIL=="NLB", "Native", ifelse(
    MBP_A$SOIL=="NHB","Native", "Pine"))))

MBP_A$BURN<-factor(ifelse(MBP_A$SOIL=="NLB","Low Burn",ifelse(
  MBP_A$SOIL=="PLB","Low Burn",ifelse(
    MBP_A$SOIL=="NHB","High Burn",ifelse(
      MBP_A$SOIL=="PHB","High Burn","Unburnt")))))

#20171107--------
TEST_A<-MBP_A%>%
  filter(SITE=="Native" & BURN=="Unburnt")
anova(lm(MBP~TREAT, data=TEST_A))

TEST_B<-MBP_A%>%
  filter(SITE=="Native" & BURN=="Low Burn")
anova(lm(MBP~TREAT, data=TEST_B))

TEST_C<-MBP_A%>%
  filter(SITE=="Native" & BURN=="High Burn")
anova(lm(MBP~TREAT, data=TEST_C))

TEST_D<-MBP_A%>%
  filter(SITE=="Pine" & BURN=="Unburnt")
anova(lm(MBP~TREAT, data=TEST_D))

TEST_E<-MBP_A%>%
  filter(SITE=="Pine" & BURN=="Low Burn")
anova(lm(MBP~TREAT, data=TEST_E))

TEST_F<-MBP_A%>%
  filter(SITE=="Pine" & BURN=="High Burn")
anova(lm(MBP~TREAT, data=TEST_F))


TEST_POOLED<-MBP_A%>%
  filter(BURN=="Unburnt")
anova(lm(MBP~TREAT, data=TEST_POOLED))

TEST_POOLED<-MBP_A%>%
  filter(BURN!="Unburnt")
anova(lm(MBP~TREAT, data=TEST_POOLED))

#20171107 END---------------
MBP_A<-MBP_A[,-1]

MBP_T<-aggregate(MBP_A$MBP, list(BURN=MBP_A$BURN, SITE=MBP_A$SITE, TREAT=MBP_A$TREAT), FUN=mean) #mean per treatment
se<-aggregate(MBP_A$MBP, list(BURN=MBP_A$BURN, SITE=MBP_A$SITE, TREAT=MBP_A$TREAT), FUN=st.err) #SE per treatment
colnames(MBP_T)<-c("BURN","SOIL","TREAT","X") #correct the collumn names

MBP_T$se<-se$x #combine the dfs
MBP_T$ymax<-MBP_T$X+MBP_T$se
MBP_T$ymin<-MBP_T$X-MBP_T$se  #these variables are to map the error bars.

#remove(MBP_A)
remove(se)
remove(MBPt)

MBP_T$TREAT<-factor(ifelse(
  MBP_T$TREAT=="C","C+",ifelse(
    MBP_T$TREAT=="N","N+",ifelse(
      MBP_T$TREAT=="P","P+",ifelse(
        MBP_T$TREAT=="CN","C+N+",ifelse(
          MBP_T$TREAT=="CP","C+P+",ifelse(
            MBP_T$TREAT=="NP","N+P+",ifelse(
              MBP_T$TREAT=="CNP","C+N+P+","Blank")))))))) #Correct the treatment names

MBP_T$TREAT<-factor(MBP_T$TREAT,levels(MBP_T$TREAT)[c(1,6,8,7,2,3,5,4)]) #correct the order
MBP_T$BURN<-factor(MBP_T$BURN,levels(MBP_T$BURN)[c(3,2,1)])

MBP_T<-MBP_T[order(MBP_T$TREAT),] #sort
MBP_T<-MBP_T[order(MBP_T$BURN),] #sort
MBP_T<-MBP_T[order(MBP_T$SOIL),]

ggplot(data=MBP_T, aes(x=TREAT, y=X, ymin=ymin, ymax=ymax)) +
  facet_grid(SOIL~BURN) +
  geom_bar(stat="identity", fill="grey50") + 
  geom_errorbar(aes(width=0.2)) +
  xlab("Treatment") +
  ylab(expression(paste("MBP (",mu,"gP/gSoil)"))) +
  scale_y_continuous(expand = c(0, 0), limits=c(0,0.9)) +
  theme(panel.background=element_rect(fill="white"), 
        panel.border = element_rect(linetype = "solid", fill = NA),
        strip.text.y=element_text(size=10),
        strip.text.x=element_text(angle=0, size=10),
        axis.text.x=element_text(angle = +90, hjust = 1)) +
  ggsave("nutrilim_MBPt2.svg",width=6, height=6)

MBP_U<-subset(MBP_A, MBP_A$BURN=="Unburnt")
MBP_LB<-subset(MBP_A, MBP_A$BURN=="Low Burn")
MBP_HB<-subset(MBP_A, MBP_A$BURN=="High Burn")

MBP_NUB<-subset(MBP_U,MBP_U$SITE=="Native")
MBP_NLB<-subset(MBP_LB,MBP_LB$SITE=="Native")
MBP_NHB<-subset(MBP_HB,MBP_HB$SITE=="Native")
MBP_PUB<-subset(MBP_U,MBP_U$SITE=="Pine")
MBP_PLB<-subset(MBP_LB,MBP_LB$SITE=="Pine")
MBP_PHB<-subset(MBP_HB,MBP_HB$SITE=="Pine")


model<-aov(MBP~TREAT, data=MBP_NUB)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)

model<-aov(MBP~TREAT, data=MBP_NLB)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)

model<-aov(MBP~TREAT, data=MBP_NHB)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)

model<-aov(MBP~TREAT, data=MBP_PUB)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)

model<-aov(MBP~TREAT, data=MBP_PLB)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)

model<-aov(MBP~TREAT, data=MBP_PHB)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)


#----------------------------------------------------------------------------- Analysis per fire history
MBP<-MBPt

MBP$BURN<-factor(ifelse(MBP$SOIL=="NLB","Burnt",ifelse(
  MBP$SOIL=="PLB","Burnt",ifelse(
    MBP$SOIL=="NHB","Burnt",ifelse(
      MBP$SOIL=="PHB","Burnt","Unburnt")))))

MBP<-MBP[,-1]

se<-aggregate(MBP$MBP, list(BURN=MBP$BURN, TREAT=MBP$TREAT), FUN=st.err) #SE per burn
MBP<-aggregate(MBP$MBP, list(BURN=MBP$BURN, TREAT=MBP$TREAT), FUN=mean) #mean per burn
colnames(MBP)<-c("BURN","TREAT","X") #correct the collumn names

MBP$se<-se$x #combine the dfs
MBP$ymax<-MBP$X+MBP$se
MBP$ymin<-MBP$X-MBP$se  #these variables are to map the error bars.

remove(se) #cleanup

MBP$TREAT<-factor(ifelse(
  MBP$TREAT=="C","C+",ifelse(
    MBP$TREAT=="N","N+",ifelse(
      MBP$TREAT=="P","P+",ifelse(
        MBP$TREAT=="CN","C+N+",ifelse(
          MBP$TREAT=="CP","C+P+",ifelse(
            MBP$TREAT=="NP","N+P+",ifelse(
            MBP$TREAT=="CNP","C+N+P+","Blank")))))))) #Correct the treatment names

MBP$TREAT<-factor(MBP$TREAT,levels(MBP$TREAT)[c(1,2,8,5,6,7,3,4)]) #correct the order
MBP$BURN<-factor(MBP$BURN,levels(MBP$BURN)[c(2,1)])
MBP<-MBP[order(MBP$TREAT),] #sort
MBP<-MBP[order(MBP$BURN),] #sort

ggplot(data=MBP, aes(x=TREAT, y=X, ymin=ymin, ymax=ymax)) +
  facet_wrap(~BURN) +
  geom_bar(stat="identity", fill="grey50") + 
  geom_errorbar(aes(width=0.2)) +
  xlab("Treatment") +
  ylab(expression(paste("MBP (",mu,"gP/gSoil)"))) +
  scale_y_continuous(expand = c(0, 0), limits=c(0,0.7)) +
  theme(panel.background=element_rect(fill="white"), 
        panel.border = element_rect(linetype = "solid", fill = NA),
        strip.text.x=element_text(angle=0, size=12),
        axis.text.x=element_text(angle = +90, hjust = 1)) +
  ggsave("nutrilim_MBP1.svg",width=6, height=6)


MBPt$BURMBP<-factor(ifelse(MBPt$SOIL=="NLB","B",ifelse(
  MBPt$SOIL=="PLB","B",ifelse(
    MBPt$SOIL=="NHB","B",ifelse(
      MBPt$SOIL=="PHB","B","U")))))

MBP_B<-subset(MBPt, MBPt$BURN=="B")
MBP_U<-subset(MBPt, MBPt$BURN=="U")

model<-aov(MBP~TREAT, data=MBP_U)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)

model<-aov(MBP~TREAT, data=MBP_B)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)