#Packages
library("agricolae")
library("car")
library("ggplot2")
library(dplyr)#for manipulating data

st.err <- function(x) {sd(x)/sqrt(length(x))} #funsction to determine the standard error

#Create the environment
setwd("/Volumes/users9/Documents/02 Data/01 EXP1  Nutrilim")

RSPt=read.csv("2015NutriLimRSPt.csv") #read the data

#----------------------------------------------------------------------------- Analysis per amendment
RSP_A<-RSPt
RSP_A$SITE<-factor(ifelse(RSP_A$SOIL=="NUB","Native",ifelse(
  RSP_A$SOIL=="NLB", "Native", ifelse(
    RSP_A$SOIL=="NHB","Native", "Pine"))))

RSP_A$BURN<-factor(ifelse(RSP_A$SOIL=="NLB","Low Burn",ifelse(
  RSP_A$SOIL=="PLB","Low Burn",ifelse(
    RSP_A$SOIL=="NHB","High Burn",ifelse(
      RSP_A$SOIL=="PHB","High Burn","Unburnt")))))

#20171107--------
TEST_A<-RSP_A%>%
  filter(SITE=="Native" & BURN=="Unburnt")
anova(lm(RSP~TREAT, data=TEST_A))

TEST_B<-RSP_A%>%
  filter(SITE=="Native" & BURN=="Low Burn")
anova(lm(RSP~TREAT, data=TEST_B))

TEST_C<-RSP_A%>%
  filter(SITE=="Native" & BURN=="High Burn")
anova(lm(RSP~TREAT, data=TEST_C))

TEST_D<-RSP_A%>%
  filter(SITE=="Pine" & BURN=="Unburnt")
anova(lm(RSP~TREAT, data=TEST_D))

TEST_E<-RSP_A%>%
  filter(SITE=="Pine" & BURN=="Low Burn")
anova(lm(RSP~TREAT, data=TEST_E))

TEST_F<-RSP_A%>%
  filter(SITE=="Pine" & BURN=="High Burn")
anova(lm(RSP~TREAT, data=TEST_F))


TEST_POOLED<-RSP_A%>%
  filter(BURN=="Unburnt")
anova(lm(RSP~TREAT, data=TEST_POOLED))

TEST_POOLED<-RSP_A%>%
  filter(BURN!="Unburnt")
anova(lm(RSP~TREAT, data=TEST_POOLED))

#20171107 END---------------


RSP_A<-RSP_A[,-1]

RSP_T<-aggregate(RSP_A$RSP, list(BURN=RSP_A$BURN, SITE=RSP_A$SITE, TREAT=RSP_A$TREAT), FUN=mean) #mean per treatment
se<-aggregate(RSP_A$RSP, list(BURN=RSP_A$BURN, SITE=RSP_A$SITE, TREAT=RSP_A$TREAT), FUN=st.err) #SE per treatment
colnames(RSP_T)<-c("BURN","SOIL","TREAT","X") #correct the collumn names

RSP_T$se<-se$x #combine the dfs
RSP_T$ymax<-RSP_T$X+RSP_T$se
RSP_T$ymin<-RSP_T$X-RSP_T$se  #these variables are to map the error bars.

#remove(RSP_A)
remove(se)
remove(RSPt)

RSP_T$TREAT<-factor(ifelse(
  RSP_T$TREAT=="C","C+",ifelse(
    RSP_T$TREAT=="N","N+",ifelse(
      RSP_T$TREAT=="P","P+",ifelse(
        RSP_T$TREAT=="CN","C+N+",ifelse(
          RSP_T$TREAT=="CP","C+P+",ifelse(
            RSP_T$TREAT=="NP","N+P+",ifelse(
              RSP_T$TREAT=="CNP","C+N+P+","Blank")))))))) #Correct the treatment names

RSP_T$TREAT<-factor(RSP_T$TREAT,levels(RSP_T$TREAT)[c(1,6,8,7,2,3,5,4)]) #correct the order
RSP_T$BURN<-factor(RSP_T$BURN,levels(RSP_T$BURN)[c(3,2,1)])

RSP_T<-RSP_T[order(RSP_T$TREAT),] #sort
RSP_T<-RSP_T[order(RSP_T$BURN),] #sort
RSP_T<-RSP_T[order(RSP_T$SOIL),]

ggplot(data=RSP_T, aes(x=TREAT, y=X, ymin=ymin, ymax=ymax)) +
  facet_grid(SOIL~BURN) +
  geom_bar(stat="identity", fill="grey50") + 
  geom_errorbar(aes(width=0.2)) +
  xlab("Treatment") +
  ylab("mgCO2-C/gOC") +
  scale_y_continuous(expand = c(0, 0), limits=c(0,210)) +
  theme(panel.background=element_rect(fill="white"), 
        panel.border = element_rect(linetype = "solid", fill = NA),
        strip.text.y=element_text(size=10),
        strip.text.x=element_text(angle=0, size=10),
        axis.text.x=element_text(angle = +90, hjust = 1)) +
  ggsave("nutrilim_RSPt.svg",width=6, height=6)

RSP_U<-subset(RSP_A, RSP_A$BURN=="Unburnt")
RSP_LB<-subset(RSP_A, RSP_A$BURN=="Low Burn")
RSP_HB<-subset(RSP_A, RSP_A$BURN=="High Burn")

RSP_NUB<-subset(RSP_U,RSP_U$SITE=="Native")
RSP_NLB<-subset(RSP_LB,RSP_LB$SITE=="Native")
RSP_NHB<-subset(RSP_HB,RSP_HB$SITE=="Native")
RSP_PUB<-subset(RSP_U,RSP_U$SITE=="Pine")
RSP_PLB<-subset(RSP_LB,RSP_LB$SITE=="Pine")
RSP_PHB<-subset(RSP_HB,RSP_HB$SITE=="Pine")


model<-aov(RSP~TREAT, data=RSP_NUB)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)

model<-aov(RSP~TREAT, data=RSP_NLB)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)

model<-aov(RSP~TREAT, data=RSP_NHB)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)

model<-aov(RSP~TREAT, data=RSP_PUB)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)

model<-aov(RSP~TREAT, data=RSP_PLB)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)

model<-aov(RSP~TREAT, data=RSP_PHB)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)


#----------------------------------------------------------------------------- Analysis per fire history

RSP<-aggregate(RSPt$RSP, list(BURN=RSPt$BURN, TREAT=RSPt$TREAT), FUN=mean) #mean per burn
se<-aggregate(RSPt$RSP, list(BURN=RSPt$BURN, TREAT=RSPt$TREAT), FUN=st.err) #SE per burn
colnames(RSP)<-c("BURN","TREAT","X") #correct the collumn names

RSP$se<-se$x #combine the dfs
RSP$ymax<-RSP$X+RSP$se
RSP$ymin<-RSP$X-RSP$se  #these variables are to map the error bars.

remove(se) #cleanup

RSP$BURN<-factor(ifelse(RSP$BURN=="B","Burnt","Unburnt"))
RSP$TREAT<-factor(ifelse(
  RSP$TREAT=="C","C+",ifelse(
    RSP$TREAT=="N","N+",ifelse(
      RSP$TREAT=="P","P+",ifelse(
        RSP$TREAT=="CN","C+N+",ifelse(
          RSP$TREAT=="CP","C+P+",ifelse(
            RSP$TREAT=="NP","N+P+",ifelse(
            RSP$TREAT=="CNP","C+N+P+","Blank")))))))) #Correct the treatment names

RSP$TREAT<-factor(RSP$TREAT,levels(RSP$TREAT)[c(1,6,8,7,2,3,5,4)]) #correct the order
RSP$BURN<-factor(RSP$BURN,levels(RSP$BURN)[c(2,1)])
RSP<-RSP[order(RSP$TREAT),] #sort
RSP<-RSP[order(RSP$BURN),] #sort

ggplot(data=RSP, aes(x=TREAT, y=X, ymin=ymin, ymax=ymax)) +
  facet_wrap(~BURN) +
  geom_bar(stat="identity", fill="grey50") + 
  geom_errorbar(aes(width=0.2)) +
  xlab("Treatment") +
  ylab("mgCO2-C/gOC") +
  scale_y_continuous(expand = c(0, 0), limits=c(0,160)) +
  theme(panel.background=element_rect(fill="white"), 
        panel.border = element_rect(linetype = "solid", fill = NA),
        strip.text.x=element_text(angle=0, size=12),
        axis.text.x=element_text(angle = +90, hjust = 1)) +
  ggsave("nutrilim_RSP1.svg",width=6, height=6)

RSP_B<-subset(RSPt, RSPt$BURN=="B")
RSP_U<-subset(RSPt, RSPt$BURN=="U")

model<-aov(RSP~TREAT, data=RSP_U)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)

model<-aov(RSP~TREAT, data=RSP_B)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)